@@ -24,15 +24,15 @@ __author__ = "Paulin-Dev"
 __copyright__ = "Copyright 2022, MyTUI"
 __credits__ = []
 __license__ = "MIT"
-__version__ = "1.0.0"
+__version__ = "1.0.6"
 __maintainer__ = "Paulin-Dev"
 __email__ = ""
 __status__ = "Development"
 
 
 # Constants
-HORIZONTAL_BAR = '─'
-VERTICAL_BAR = '│'
+HORIZONTAL_BAR = b'\xe2\x94\x80'.decode()
+VERTICAL_BAR = b'\xe2\x94\x82'.decode()
            
 
 class MyTUI:
@@ -261,16 +261,16 @@ class MyTUI:
         if title:
             bar_length = width() - len(title) - 10
             bonus = 1 if len(title) % 2 != 0 and width() % 2 == 0 or len(title) % 2 == 0 and width() % 2 != 0 else 0
-            print(on_blue(" ") + black_on_gray(f'┌{HORIZONTAL_BAR*((bar_length//2))}┤  ') + red_on_gray(title) + black_on_gray(f'  ├{HORIZONTAL_BAR*((bar_length//2)-1+bonus)}┐') + on_blue("  "))
+            print(on_blue(" ") + black_on_gray(f'{b"\xe2\x94\x8c".decode()}{HORIZONTAL_BAR*((bar_length//2))}{b"\xe2\x94\xa4".decode()}  ') + red_on_gray(title) + black_on_gray(f'  {b"\xe2\x94\x9c".decode()}{HORIZONTAL_BAR*((bar_length//2)-1+bonus)}{b"\xe2\x94\x90".decode()}') + on_blue("  "))
         else:
-            print(on_blue(" ") + black_on_gray(f'┌{HORIZONTAL_BAR*(width()-5)}┐') + on_blue("  "))
+            print(on_blue(" ") + black_on_gray(f'{b"\xe2\x94\x8c".decode()}{HORIZONTAL_BAR*(width()-5)}{b"\xe2\x94\x90".decode()}') + on_blue("  "))
         print(f'{on_blue(" ") + black_on_gray(VERTICAL_BAR + " "*(width()-5) + VERTICAL_BAR) + on_black(" ") + on_blue(" ")}')
 
     @classmethod
     def __display_bottom(cls, spaces: int, extra_line: bool = True, yesno: bool = False, menu: bool = False, input: bool = False) -> None:
         if extra_line:
             print(f'{on_blue(" ") + black_on_gray(VERTICAL_BAR + " "*(width()-5) + VERTICAL_BAR) + on_black(" ") + on_blue(" ")}')
-        print(on_blue(" ") + black_on_gray(f'└{HORIZONTAL_BAR*(width()-5)}┘') + on_black(" ") + on_blue(" "))
+        print(on_blue(" ") + black_on_gray(f'{b"\xe2\x94\x94".decode()}{HORIZONTAL_BAR*(width()-5)}{b"\xe2\x94\x98".decode()}') + on_black(" ") + on_blue(" "))
         print(on_blue("  ") + on_black(" "*(width()-3) + on_blue(" ")))
 
         for i in range(spaces):
